# PypeIt
The Python Spectroscopic Data Reduction Pipeline.  For
documentation visit:

http://pypeit.readthedocs.io

and/or see our HOWTO:

https://tinyurl.com/pypeit-howto

and/or join our PypeIt Users Slack 
(the invite is recorded in this Issue:
https://github.com/pypeit/PypeIt/issues/676)

# Please cite:


[![DOI](https://zenodo.org/badge/DOI/10.5281/zenodo.3506873.svg)](https://doi.org/10.5281/zenodo.3506873)



# Instruments Served
* Gemini/GNIRS
* Gemini/GMOS 
* Lick/Kast 
* Lick/APF (planned)
* Magellan/MagE
* Keck/DEIMOS
* Keck/LRIS 
* Keck/MOSFIRE (soon)
* Keck/NIRES
* Keck/NIRSPEC (low-dispersion)
* VLT/X-Shooter
* VLT/FORS2
* WHT/ISIS

# Requirements

(see `./pypeit/requirements.txt`)

* python
* numpy
* scipy
* matplotlib
* astropy
* ginga
* h5py
* future
* PyYAML
* linetools
* IPython
* scikit-learn
* configobj

# Code of Conduct
(see `./doc/codeconduct.rst`)

# License
This program is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation, either version 3 of the License, or
any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

Permission is granted to copy, distribute and/or modify the supporting document
under the terms of the GNU Free Documentation License, Version 1.3
or any later version published by the Free Software Foundation;
with no Invariant Sections, no Front-Cover Texts, and no Back-Cover Texts.
A copy of the license is included in the section entitled "GNU
Free Documentation License".
